@@ -27,10 +27,13 @@ class KafkaWriter(Writer):
 
     def write_weibo(self, weibo):
         for w in weibo:
+            w.user_id = self.user.id
             for topic in self.weibo_topics:
                 self.producer.send(topic, value=w.__dict__)
 
     def write_user(self, user):
+        self.user = user
+
         for topic in self.user_topics:
             self.producer.send(topic, value=user.__dict__)
 
